Learn R Programming

SOMMD (version 0.1.2)

calc.dists: Calculation of Distances

Description

Compute the pairwise distance matrix of a given set of coordinates, and only retain to some selected distances

Usage

calc.dists(coord, mol.1_id = FALSE, mol.2_id = FALSE, sele = FALSE)

Value

A matrix contaning the selected distances for a frame

Arguments

coord

matrix of N atomic coordinates (N rows, 3 columns)

mol.1_id

vector containing the index of the first molecule for intermolecular distances only

mol.2_id

vector containing the index of the second molecule for intermolecular distances only

sele

contains the selection of distances coming from the native_contacts function

Author

Stefano Mottastefano.motta@unimib.it