powered by
Function to compute the per-neuron population
neur.population(SOM, start = 1, end = length(SOM$unit.classif), N = 1)
A vector containing the per-neuron population
the SOM object
a vector containing the start frames of each replica (usually contained in trj$start if replicas were merged with cat_trj)
a vector containing the end frames of each replica (usually contained in trj$end if replicas were merged with cat_trj)
An integer for the portion (replica) of the simulations to be plotted
Stefano Motta stefano.motta@unimib.it
#Read example SOM data som_model <- readRDS(system.file("extdata", "SOM_HIFa.rds", package = "SOMMD")) pop <- neur.population(som_model)
Run the code above in your browser using DataLab