Learn R Programming

SOMMD (version 0.1.2)

silhouette.profile: Silhouette profile

Description

Function to compute the silhouette profile for the Nclus cluster of the SOM neurons

Usage

silhouette.profile(
  SOM,
  Nclus,
  dist_clust = "euclidean",
  clust_method = "complete"
)

Value

A vector of silhouette profile computed with the cluster package

Arguments

SOM

the SOM object to cluster

Nclus

the cluster number on which the silhouette profile will be computed

dist_clust

the metric for the distance calculation

clust_method

the method for the clustering (passed to the hclust function

Author

Stefano Motta stefano.motta@unimib.it

Examples

Run this code
#Read example SOM data
som_model <- readRDS(system.file("extdata", "SOM_HIFa.rds", package = "SOMMD"))
#Compute the silhouette profile
sil_pro <- silhouette.profile(som_model, Nclus=5, clust_method="complete")

Run the code above in your browser using DataLab