Compute the pairwise distance matrix of a given set of coordinates, and only retain to some selected distances
calc.dists(coord, mol.1_id = FALSE, mol.2_id = FALSE, sele = FALSE)A matrix contaning the selected distances for a frame
matrix of N atomic coordinates (N rows, 3 columns)
vector containing the index of the first molecule for intermolecular distances only
vector containing the index of the second molecule for intermolecular distances only
contains the selection of distances coming from the native_contacts function
Stefano Mottastefano.motta@unimib.it